==> prodimopy-0.7-py2.py3-none-any.whl: prodimopy/script_params.py <==
"""
Script to manipulate the Parameter.in file of ProDiMo. 

Currently only on parameter can be changed or appended to an existing file. 

This is still experimental stuff ... .  

TODO: maybe automatic backup of old file ... 
TODO: maybe change of multiple parameters ... 
TODO: maybe make some checks (e.g. by finding out the type of the old parameter and
      new value must have the same type)
TODO: make a routine so that it can be use also in other scripts 
"""
from __future__ import print_function
from __future__ import division
from __future__ import unicode_literals

# the above two statement are for phyton2 pyhton3 compatibility.
# With this statmens you can write python3 code and it should also work
# in python2 (depends on your code) 

# this is for the argument parser included in python
import argparse
import glob
import os


# The main routine is require to have an entry point. 
# It is not necessary if you want to write your own script.
def main(args=None):
  ###############################################################################
  # Command line parsing
  # this is optional you do not have to do it this way. 
  # You can use the prodimopy module in any way you want
  parser = argparse.ArgumentParser(description='Changing of parameters in the ProDiMo Parameter files. ')
  parser.add_argument('paramname', help='The name of the Parameter in Parameter.in.')  
  parser.add_argument('value', help='The value of the parameter to change.')  
  parser.add_argument('-direxp',default=".",help="Change Parameters in all the given model directories. Just pass a regex that is understood by glob.glob")
  parser.add_argument('-file', required=False, default="Parameter.in", help='File path to the Parameter file. DEFAULT: Parameer.in')
  args = parser.parse_args()
  
  print("paramname: ", args.paramname)
  print("value: ", args.value)
  print("-direxp: ", args.direxp)
  print("-file: ", args.file)
  
  # for this I search
  param="! "+args.paramname+" "
    
  # get the directories
  dirs=glob.glob(args.direxp)
  print("")
  
  for dir in dirs:
    print("Change Parameter file: "+dir+"/"+args.file)
    f=open(dir+"/"+args.file)
    inlines=f.readlines()
    f.close()

    replaced=False
    for i in range(len(inlines)):
      ip=inlines[i].find(param)
      if ip > -1:
        val=inlines[i][0:ip-1]
        rest=inlines[i][ip:]
        lval=len(val)
        lnewval=len(args.value)
        if lval > lnewval:
          newval=args.value+" "*(lval-lnewval)
        elif lval < lnewval:
          newval=args.value+"  "
        else:
          newval=args.value  
        
        inlines[i]=newval+rest
        print("change : ",inlines[i])
        replaced=True  
  
    if not replaced:
      inlines.append(args.value+"  "+param+"\n")
      print("append : ",inlines[-1])

    f=open(dir+"/"+args.file,"w")
    f.write("".join(inlines))
    f.close()

  
  #print(inlines)

==> prodimopy-0.10.1-py2.py3-none-any.whl: prodimopy/script_params.py <==
"""
Script to manipulate the Parameter.in file of ProDiMo. 

Currently only on parameter can be changed or appended to an existing file. 

This is still experimental stuff ... .  

TODO: maybe automatic backup of old file ... 
TODO: maybe change of multiple parameters ... 
TODO: maybe make some checks (e.g. by finding out the type of the old parameter and
      new value must have the same type)
TODO: make a routine so that it can be use also in other scripts 
"""
from __future__ import print_function
from __future__ import division
from __future__ import unicode_literals

# the above two statement are for phyton2 pyhton3 compatibility.
# With this statmens you can write python3 code and it should also work
# in python2 (depends on your code) 

# this is for the argument parser included in python
import argparse
import glob
import os
import prodimopy.utils as putils




# The main routine is require to have an entry point. 
# It is not necessary if you want to write your own script.
def main(args=None):
  ###############################################################################
  # Command line parsing
  # this is optional you do not have to do it this way. 
  # You can use the prodimopy module in any way you want
  parser = argparse.ArgumentParser(description='Changing of parameters in the ProDiMo Parameter files. ')
  parser.add_argument('paramname', help='The name of the Parameter in Parameter.in.')  
  parser.add_argument('value', help='The value of the parameter to change.')  
  parser.add_argument('-direxp',default=".",help="Change Parameters in all the given model directories. Just pass a regex that is understood by glob.glob")
  parser.add_argument('-file', required=False, default="Parameter.in", help='File path to the Parameter file. DEFAULT: Parameer.in')
  args = parser.parse_args()
  
  print("paramname: ", args.paramname)
  print("value: ", args.value)
  print("-direxp: ", args.direxp)
  print("-file: ", args.file)
  
  # for this I search
  param="! "+args.paramname.strip()+" "
    
  # get the directories
  dirs=glob.glob(args.direxp)
  print("")
  
  for dir in dirs:
    print("Change Parameter file: "+dir+"/"+args.file)
    f=open(dir+"/"+args.file)
    inlines=f.readlines()
    f.close()

    putils.set_param(inlines, param, args.value)

    f=open(dir+"/"+args.file,"w")
    f.write("".join(inlines))
    f.close()
